========================
Release notes for parquery
========================

Release  0.1.8
==============
- Ensure that groupby columns are seen as categorical series

Release  0.1.7
==============
- Fix Python 2 legacy differences in pyarrow

Release  0.1.6
==============
- Fix Python 2 requirements

Release  0.1.5
==============
- Updated Links

Release  0.1.4
==============
- Added arrow aggregation method

Release  0.1.3
==============
- Introduced writer debug output

Release  0.1.2
==============
- Updated manifest

Release  0.1.1
==============
- Updated requirements for dependencies based on the python version

Release  0.1.1
==============
- Inital release

.. Local Variables:
.. mode: rst
.. coding: utf-8
.. fill-column: 72
.. End:
